#ifndef FREERTOS_CONFIG_H
#define FREERTOS_CONFIG_H

// Нужно исключительно для индексации в Eclipse
#ifndef __AVR_ATmega128RFA1__
#define __AVR_ATmega128RFA1__
#endif

#include <avr/io.h>

/**
 \brief 1 -- вытесняющее ядро, 0 - кооперативное ядро.
 */
#define configUSE_PREEMPTION		1
/**
 \brief Использовать функцию idle hook во время бездействия системы.
 */
#define configUSE_IDLE_HOOK			0
/**
 \brief Использовать функцию tick hook во время срабатывания TICK таймера.
 */
#define configUSE_TICK_HOOK			0
/**
 \brief Частота CPU.
 */
#define configCPU_CLOCK_HZ			( 16000000L )
/**
 \brief Частота системного TICK таймера.
 */
#define configTICK_RATE_HZ			( ( TickType_t ) 1000 )
/**
 \brief Максимальный приоритет задачи.
 */
#define configMAX_PRIORITIES		( 2 )
/**
 \brief Минимальный размер стека для задачи.
 */
#define configMINIMAL_STACK_SIZE	( ( unsigned short ) 85 )
/**
 \brief Общий размер "кучи" -- память для выделения стеков.
 */
#define configTOTAL_HEAP_SIZE		( (size_t ) ( 1500 ) )
/**
 \brief Размер имени для задачи. Используется только для отладки.
 */
#define configMAX_TASK_NAME_LEN		( 8 )
/**
 \brief Использование трассировки.
 */
#define configUSE_TRACE_FACILITY	0
/**
 \brief Используем 16-битный счетчик тиков.
 */
#define configUSE_16_BIT_TICKS		1

/**
 \brief Определения для Сопрограмм (Co-routine). Не используем.
        1 -- будет.
 */
#define configUSE_CO_ROUTINES 		0
#define configMAX_CO_ROUTINE_PRIORITIES ( 1 )

/**
 \brief 0 -- соответствующая функция не будет использована в проекте,
        1 -- будет.
 */
#define INCLUDE_vTaskPrioritySet		0
#define INCLUDE_uxTaskPriorityGet		0
#define INCLUDE_vTaskDelete				0
#define INCLUDE_vTaskCleanUpResources	0
#define INCLUDE_vTaskSuspend			0
#define INCLUDE_vTaskDelayUntil			0
#define INCLUDE_vTaskDelay				1


#endif /* FREERTOS_CONFIG_H */
